@@ -1,9 +1,11 @@
+import asyncio
 try:
     import ujson as json
 except ModuleNotFoundError:
     import json
 from pathlib import Path
 from typing import Literal
+from random import random, choice
 from nonebot.rule import to_me
 from nonebot import get_driver, logger, on_message, on_command
 from nonebot.matcher import Matcher
@@ -23,14 +25,23 @@ from nonebot.params import CommandArg
 
 superusers = get_driver().config.superusers
 
-file_path = Path(__file__).parent / "curse.json"
+cursepath = Path(__file__).parent / "curse.json"
 curse_path = Path() / "data" / "anti-insult" / "curse.json"
 curse_path.parent.mkdir(parents=True, exist_ok=True)
 
 curse_list = (
     json.loads(curse_path.read_text("utf-8"))
     if curse_path.is_file()
-    else json.loads(file_path.read_text("utf-8"))
+    else json.loads(cursepath.read_text("utf-8"))
+)
+
+flymopath = Path(__file__).parent / "flymo.json"
+flymo_path = Path() / "data" / "anti-insult" / "flymo.json"
+
+flymo_list = (
+    json.loads(flymo_path.read_text('utf-8'))
+    if flymo_path.is_file()
+    else json.loads(flymopath.read_text("utf-8"))
 )
 
 blacklist = {'user': []}
@@ -60,6 +71,15 @@ def save_curse_path() -> None:
     )
 
 
+
+def save_flymo_path() -> None:
+    flymo_path.write_text(
+        json.dumps(flymo_list, indent=2, ensure_ascii=False),
+        encoding="utf-8"
+    )
+
+
+
 def handle_curse_list(
     arg,
     mode: Literal["add", "del"],
@@ -104,12 +124,48 @@ async def _(arg: Message = CommandArg()):
 
 
 
+enable_flymo = on_command(
+    '启用飞妈令',
+    aliases={'启用飞马令','启用飞🐴令','启用飞🐎令'},
+    permission=SUPERUSER,
+    priority=1,
+    block=True
+)
+
+@enable_flymo.handle()
+async def _():
+    flymo_list['enable'] = True
+    save_flymo_path()
+    await enable_flymo.finish('Done.')
+
+
+
+disable_flymo = on_command(
+    '禁用飞妈令',
+    aliases={'禁用飞马令','禁用飞🐴令','禁用飞🐎令'},
+    permission=SUPERUSER,
+    priority=1,
+    block=True
+)
+
+@disable_flymo.handle()
+async def _():
+    flymo_list['enable'] = False
+    save_flymo_path()
+    await disable_flymo.finish('Done.')
+
+
+
 anti_abuse = on_message(rule=to_me(), priority=15, block=False)
 
 @anti_abuse.handle()
 async def _(bot: Bot, event: MessageEvent, matcher: Matcher):
     for i in curse_list['curse']:
         if i in str(event.get_message()):
+            matcher.stop_propagation()
+            if flymo_list['enable']:
+                await asyncio.sleep(random()+1)
+                await anti_abuse.finish(choice(flymo_list['flymo']), at_sender=True)
             user_id = event.user_id
             try:
                 if isinstance(event, GroupMessageEvent):
@@ -121,7 +177,6 @@ async def _(bot: Bot, event: MessageEvent, matcher: Matcher):
             except:
                 msg = handle_namelist(user_id)
                 logger.info(msg)
-            matcher.stop_propagation()
             await anti_abuse.finish("不理你啦！バーカー", at_sender=True)
 
 
@@ -131,7 +186,7 @@ def namelist_processor(event: MessageEvent):
     uid = str(event.user_id)
     if uid in superusers:
         return
-    if uid in blacklist:
+    if uid in blacklist['user']:
         logger.debug(f"用户 {uid} 在临时黑名单中, 忽略本次消息")
         raise IgnoredException("黑名单用户")
 
@@ -141,7 +196,7 @@ def namelist_processor_poke(event: PokeNotifyEvent):
     uid = str(event.user_id)
     if uid in superusers:
         return
-    if uid in blacklist:
+    if uid in blacklist['user']:
         logger.debug(f"用户 {uid} 在临时黑名单中, 忽略本次消息")
         raise IgnoredException("黑名单用户")
 
@@ -150,11 +205,15 @@ def namelist_processor_poke(event: PokeNotifyEvent):
 
 
 
-namelist_del = on_command("解除屏蔽", permission=SUPERUSER, priority=1, block=True)
+namelist_del = on_command("解除屏蔽", aliases={"摘口球"}, permission=SUPERUSER, priority=1, block=True)
 
 @namelist_del.handle()
 async def _(bot: Bot, event: MessageEvent, arg: Message = CommandArg()):
-    uids = arg.extract_plain_text().strip().split()
+    uids = (
+        [at.data['qq'] for at in event.get_message()['at']]
+        if event.get_message()['at']
+        else arg.extract_plain_text().strip().split()
+    )
     if not uids:
         await namelist_del.finish("用法: \n解除屏蔽 qq qq1 qq2 ...")
     for uid in uids:
